@@ -39,7 +39,7 @@ def set_dataframe_columntypes(df):
         df['idCampaign'] = df['idCampaign'].astype('Int64')
         df['idCampaign'] = df['idCampaign'].apply(str)
     if 'BulkStatus' in df:
-        df['BulkStatus']=df['BulkStatus'].astype('Int64')
+        df['BulkStatus'] = df['BulkStatus'].astype('Int64')
         df['BulkStatus'] = df['BulkStatus'].apply(str)
     if 'campaign_bulk_date' in df:
         df['campaign_bulk_date'] = df['campaign_bulk_date'].astype('object')
@@ -538,7 +538,21 @@ def clean_mxtype(df, mxtypes):
     return df
 
 
-def clean_mxtype_using_dictionary(df, mx_bv_dict, mx_prob_dict):
+def create_class_dictionaries(df,class_to_use:str):
+    df['BV']=df['BV'].fillna(0)
+    groupby = df[[class_to_use, 'BV', 'IDEmailStatus']].groupby(class_to_use).agg(BV=('BV', 'mean'),
+                                                                                 Conversions=(
+                                                                                     'IDEmailStatus', 'mean'))
+    groupby = groupby.reset_index()
+    list_dict = groupby.to_dict(orient='records')
+    conversion_dict = {}
+    bv_dict = {}
+    for element in list_dict:
+        conversion_dict[f'{element[class_to_use]}'] = element['Conversions']
+        bv_dict[f'{element[class_to_use]}'] = element['BV']
+    return conversion_dict,bv_dict
+
+def map_conv_prob_using_dictionary(df, bv_dict, prob_dict, column:str):
     """
 
     :param df: Input Dataset
@@ -547,13 +561,14 @@ def clean_mxtype_using_dictionary(df, mx_bv_dict, mx_prob_dict):
     :return df: processed Dataset
     """
 
-    if 'MXType' not in df.columns:
+    if column not in df.columns:
         raise Exception("MXType column not preset ( Check Caps)")
-    logger.info('Defining MXTypes')
-    df['mx_bv'] = df['MXType']
-    df = df.replace({'mx_bv': mx_bv_dict})
-    df['mx_prob'] = df['MXType']
-    df = df.replace({'mx_prob': mx_prob_dict})
+    logger.info(f'Defining dict for {column}')
+    bv_col = column+"_bv"
+    df[bv_col] = df[column].map(bv_dict)
+    prob_col = column+"_prob"
+    df[prob_col] = df[column].map(prob_dict)
+    df.drop(column,axis=1,inplace=True)
     return df
 
 
